@@ -1,3 +1,3 @@
-from .saiml import SAIML
+from .saiml import SAIML,style
 from .pprint import pprint, p_value
 from .logger import *
